@@ -1,6 +1,11 @@
 matchit2full <- function(treat, X, data, distance, discarded,
                          verbose=FALSE, ...) { 
-  require(optmatch)
+  if ("optmatch" %in% .packages(all = TRUE))
+    require(optmatch)
+  else {
+    install.packages("optmatch", contriburl="http://www.stat.lsa.umich.edu/~bbh/optmatch")
+    require(optmatch)
+  }
   
   if(verbose)
     cat("Full matching... \n")
